@@ -166,7 +166,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
     """
     Saves Model at each end of the epoch when the best accuracy/loss is presented.
     """
-    def __init__(self, best_metric=float('inf'), save_root="./", save_metric='val_loss', enable=True, epoch=0):
+    def __init__(self, best_metric=float('inf'), save_root="./", save_metric='val_loss', file_name="my_model", enable=True, epoch=0):
         """
 
         Args:
@@ -185,6 +185,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
         self.save_root = save_root
         self.enable = enable
         self.save_metric = save_metric
+        self.file_name = file_name
 
     def on_epoch_end(self, epoch, logs=None):
         try:
@@ -209,7 +210,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
                     except:
                         print("Error while deleting file : {}".format(file_path))
 
-                file_name = '{}/my_model_weight_{:04d}_{}_{:03.2f}.h5'.format(self.save_root, epoch, self.save_metric, logs[self.save_metric])
+                file_name = '{}/{}_{:04d}_{}_{:03.2f}.h5'.format(self.save_root, self.file_name, epoch, self.save_metric, logs[self.save_metric])
                 print("\nBest score! saving the model to {} ...".format(file_name))
                 self.best_metric = logs[self.save_metric]
 
@@ -218,7 +219,6 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
         except Exception as e:
             print(e)
 
-
 class SparsityCallback(tf.keras.callbacks.Callback):
     """
     Computes the sparsity on each layer of the given model and saves bar plot image to the TensorBoard.
@@ -282,7 +282,7 @@ class SparsityCallback(tf.keras.callbacks.Callback):
         sparse_layer_names = []
 
         for i, (sparsity, layer_name) in enumerate(zip(sparsities, layer_names)):
-            if np.isnan(sparsity) and sparsity == 0.0:
+            if np.isnan(sparsity) or sparsity == 0.0:
                 continue
 
             sparse_levels = np.concatenate([sparse_levels, [sparsity]])
@@ -356,7 +356,7 @@ def wait_ctrl_c(pre_msg="Press Ctrl+c to quit Tensorboard", post_msg="\nExit."):
 def get_tf_callbacks(root,
                      tboard_callback=True, tboard_update_freq='epoch', tboard_histogram_freq=1, tboard_profile_batch=0,
                      confuse_callback=True, label_info=None, x_test=None, y_test=None, test_generator_=None, test_dataset=None, figure_size=(12, 10), model_out_idx=-1,
-                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0, save_metric='val_loss',
+                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0, save_metric='val_loss', save_file_name="my_model",
                      earlystop_callback=True, earlystop_monitor='val_loss', earlystop_patience=0, earlystop_restore_weights=True,
                      sparsity_callback=False, sparsity_threshold=0.05):
     """
@@ -385,6 +385,7 @@ def get_tf_callbacks(root,
         save_root (str): Model save path
         best_epoch (int): Previous Best epoch number if resuming
         save_metric (str): One of 'val_loss', 'val_accuracy'
+        save_file_name (str): Model Save Target File Name
         earlystop_callback (bool): Early Stop callback
         earlystop_monitor (str): Earlys top_monitor metric 'val_loss', 'val_accuracy'
         earlystop_patience (int): Early stop patience
@@ -430,7 +431,7 @@ def get_tf_callbacks(root,
         if not save_root:
             save_root = log_root_
         callbacks_.append(
-            ModelSaverCallback(best_metric=best_loss, save_root=save_root, epoch=best_epoch, save_metric=save_metric)
+            ModelSaverCallback(best_metric=best_loss, save_root=save_root, epoch=best_epoch, save_metric=save_metric, file_name=save_file_name)
         )
 
     if earlystop_callback:
